import axios, {
    type AxiosInstance,
    type AxiosRequestConfig,
    type AxiosResponse,
    type InternalAxiosRequestConfig
} from 'axios';
import {type ApiResponse, AXIOS_CONFIG} from "@/config/Axios_Config";
// 创建 Axios 实例
const service: AxiosInstance = axios.create(AXIOS_CONFIG);
// 请求拦截器
service.interceptors.request.use(
    (config: InternalAxiosRequestConfig) => {
        return config;
    },
    (error) => {
        return Promise.reject(error);
    }
);

// 响应拦截器
service.interceptors.response.use(
    (response: AxiosResponse) => {
        // 直接返回响应数据
        return response.data;
    },
    (error) => {
        // 统一处理错误
        console.error('Request Error:', error);
        return Promise.reject(error);
    }
);

// // 封装通用的 GET 请求
// export const get = <T>(url: string, params?: Record<string, any>): Promise<ApiResponse<T>> => {
//     return service.get(url, { params });
// };
//
// // 封装通用的 POST 请求
// export const post = <T>(url: string, data?: Record<string, any>): Promise<ApiResponse<T>> => {
//     return service.post(url, data);
// };
// // 封装通用的 delete 请求
// export const del = <T>(url: string, params?: Record<string, any>): Promise<ApiResponse<T>> => {
//     return service.delete(url, { params });
// };
//
// // 封装通用的 put 请求
// export const put = <T>(url: string, data?: Record<string, any>): Promise<ApiResponse<T>> => {
//     return service.put(url, data);
// };
export const fetchData = async <T>(
    method: 'get' | 'post' | 'put' | 'delete',
    url: string,
    paramsOrData?: Record<string, any>
): Promise<T> => {
    try {
        let response: AxiosResponse<T>;
        if (method === 'get' || method === 'delete') {
            response = await service[method](url, { params: paramsOrData });
        } else {
            response = await service[method](url, paramsOrData);
        }
            return response as T;
    } catch (error) {
        return Promise.reject(error); // 抛出错误让调用方处理
    }
};
// 导出 Axios 实例以便自定义请求
export default service;
